@@ -2,6 +2,7 @@ from cytra.exceptions import CytraException, InvalidParamError
 from cytra.application import Application
 from cytra.testing import TestingApp
 from cytra.cors import CORSAppMixin
+from cytra.i18n import I18nAppMixin
 
 __all__ = (
     CytraException,
@@ -9,5 +10,6 @@ __all__ = (
     Application,
     TestingApp,
     CORSAppMixin,
+    I18nAppMixin,
 )
-__version__ = "0.8.0"
+__version__ = "0.9.0"
